@@ -364,6 +364,23 @@ def test_array_conversion():
         with pytest.raises(RuntimeError, match="Can not convert array"):
             asarray([a])
 
+def test__array__():
+    # __array__ should work for now
+    a = ones((2, 3))
+    np.array(a)
+
+    # Test the _allow_array private global flag for disabling it in the
+    # future.
+    from .. import _array_object
+    original_value = _array_object._allow_array
+    try:
+        _array_object._allow_array = False
+        a = ones((2, 3))
+        with pytest.raises(ValueError, match="Conversion from an array_api_strict array to a NumPy ndarray is not supported"):
+            np.array(a)
+    finally:
+        _array_object._allow_array = original_value
+
 def test_allow_newaxis():
     a = ones(5)
     indexed_a = a[None, :]
@@ -436,8 +453,12 @@ def test_array_namespace():
         assert a.__array_namespace__(api_version="2021.12") is array_api_strict
     assert array_api_strict.__array_api_version__ == "2021.12"
 
+    with pytest.warns(UserWarning):
+        assert a.__array_namespace__(api_version="2024.12") is array_api_strict
+    assert array_api_strict.__array_api_version__ == "2024.12"
+
     pytest.raises(ValueError, lambda: a.__array_namespace__(api_version="2021.11"))
-    pytest.raises(ValueError, lambda: a.__array_namespace__(api_version="2024.12"))
+    pytest.raises(ValueError, lambda: a.__array_namespace__(api_version="2025.12"))
 
 def test_iter():
     pytest.raises(TypeError, lambda: iter(asarray(3)))
@@ -448,7 +469,7 @@ def test_iter():
     pytest.raises(TypeError, lambda: iter(ones((3, 3))))
 
 @pytest.mark.parametrize("api_version", ['2021.12', '2022.12', '2023.12'])
-def dlpack_2023_12(api_version):
+def test_dlpack_2023_12(api_version):
     if api_version == '2021.12':
         with pytest.warns(UserWarning):
             set_array_api_strict_flags(api_version=api_version)
@@ -456,19 +477,41 @@ def dlpack_2023_12(api_version):
         set_array_api_strict_flags(api_version=api_version)
 
     a = asarray([1, 2, 3], dtype=int8)
-
-    # Do not error
+    # Never an error
     a.__dlpack__()
-    a.__dlpack__(dl_device=CPU_DEVICE)
-    a.__dlpack__(dl_device=None)
-    a.__dlpack__(max_version=(1, 0))
-    a.__dlpack__(max_version=None)
-    a.__dlpack__(copy=False)
-    a.__dlpack__(copy=True)
-    a.__dlpack__(copy=None)
 
-    x = np.from_dlpack(a)
-    assert isinstance(x, np.ndarray)
-    assert x.dtype == np.int8
-    assert x.shape == (3,)
-    assert np.all(x == np.asarray([1, 2, 3]))
+    if api_version < '2023.12':
+        pytest.raises(ValueError, lambda:
+                      a.__dlpack__(dl_device=a.__dlpack_device__()))
+        pytest.raises(ValueError, lambda:
+                      a.__dlpack__(dl_device=None))
+        pytest.raises(ValueError, lambda:
+                      a.__dlpack__(max_version=(1, 0)))
+        pytest.raises(ValueError, lambda:
+                      a.__dlpack__(max_version=None))
+        pytest.raises(ValueError, lambda:
+                      a.__dlpack__(copy=False))
+        pytest.raises(ValueError, lambda:
+                      a.__dlpack__(copy=True))
+        pytest.raises(ValueError, lambda:
+                      a.__dlpack__(copy=None))
+    elif np.lib.NumpyVersion(np.__version__) < '2.1.0':
+        pytest.raises(NotImplementedError, lambda:
+                      a.__dlpack__(dl_device=CPU_DEVICE))
+        a.__dlpack__(dl_device=None)
+        pytest.raises(NotImplementedError, lambda:
+                      a.__dlpack__(max_version=(1, 0)))
+        a.__dlpack__(max_version=None)
+        pytest.raises(NotImplementedError, lambda:
+                      a.__dlpack__(copy=False))
+        pytest.raises(NotImplementedError, lambda:
+                      a.__dlpack__(copy=True))
+        a.__dlpack__(copy=None)
+    else:
+        a.__dlpack__(dl_device=a.__dlpack_device__())
+        a.__dlpack__(dl_device=None)
+        a.__dlpack__(max_version=(1, 0))
+        a.__dlpack__(max_version=None)
+        a.__dlpack__(copy=False)
+        a.__dlpack__(copy=True)
+        a.__dlpack__(copy=None)
